@@ -80,9 +80,9 @@ def zup2yup(Q):
     return Q
 
 
-def interpolate_zeros(col, *kind):
+def interpolate_nans(col, *kind):
     '''
-    Interpolate missing points (of value 0.)
+    Interpolate missing points (of value nan)
 
     INPUTS:
     - col: pandas column of coordinates
@@ -384,9 +384,11 @@ def triangulate_all(config):
     json_dirs_names = [k for k in pose_listdirs_names if json_folder_extension in k]
     try: 
         json_files_names = [fnmatch.filter(os.listdir(os.path.join(poseTracked_dir, js_dir)), '*.json') for js_dir in json_dirs_names]
+        json_files_names = [natural_sort(j) for j in json_files_names]
         json_tracked_files = [[os.path.join(poseTracked_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     except:
         json_files_names = [fnmatch.filter(os.listdir(os.path.join(pose_dir, js_dir)), '*.json') for js_dir in json_dirs_names]
+        json_files_names = [natural_sort(j) for j in json_files_names]
         json_tracked_files = [[os.path.join(pose_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     
     # Triangulation
@@ -426,7 +428,7 @@ def triangulate_all(config):
     nb_cams_excluded_tot['mean'] = nb_cams_excluded_tot.mean(axis = 1)
 
     # Interpolate missing values
-    Q_tot = Q_tot.apply(interpolate_zeros, axis=0, args = [interpolation_kind])
+    Q_tot = Q_tot.apply(interpolate_nans, axis=0, args = [interpolation_kind])
    
     # Create TRC file
     trc_path = make_trc(config, Q_tot, keypoints_names, f_range)
